@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009 - 2013 by Artem 'DOOMer' Galichkin                        *
+ *   Copyright (C) 2009 - 2013 by Artem 'DOOMer' Galichkin                 *
  *   doomer3d@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -13,60 +13,106 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #include "src/core/config.h"
 #include "core.h"
 
-#include <QtGui/QApplication>
-#include <QtCore/QDir>
-#include <QtCore/QFile>
-#include <QtCore/QLocale>
-#include <QtCore/QVector>
-#include <QtGui/QDesktopServices>
-
+#include <QApplication>
+#include <QStandardPaths>
+#include <QDir>
+#include <QFile>
+#include <QLocale>
+#include <QVector>
 #include <QDebug>
 
-const QString KEY_SAVEDIR = "defDir";
-const QString KEY_SAVENAME = "defFilename";
-const QString KEY_SAVEFORMAT = "defImgFormat";
-const QString KEY_DELAY_DEF = "defDelay";
-const QString KEY_DELAY = "delay";
-const QString KEY_IMG_QUALITY = "imageQuality";
-const QString KEY_FILENAMEDATE = "insDateTimeInFilename";
-const QString KEY_DATETIME_TPL = "templateDateTime";
-const QString KEY_FILENAME_TO_CLB = "CopyFilenameToClipboard";
-const QString KEY_AUTOSAVE = "autoSave";
-const QString KEY_AUTOSAVE_FIRST = "autoSaveFirst";
-const QString KEY_SHOW_TRAY = "showTrayIcon";
+#define CONFIG_FILE_DIR "screengrab"
+#define CONFIG_FILE_NAME "screengrab.conf"
 
-const QString KEY_WND_WIDTH = "windowWidth";
-const QString KEY_WND_HEIGHT = "windowHeight";
-const QString KEY_ZOOMBOX = "zoomAroundMouse";
-const QString KEY_TRAYMESSAGES = "trayMessages";
-const QString KEY_TIME_NOTIFY = "timeTrayMessages";
-const QString KEY_ALLOW_COPIES = "AllowCopies";
+#define KEY_SAVEDIR             "defDir"
+#define KEY_SAVENAME            "defFilename"
+#define KEY_SAVEFORMAT          "defImgFormat"
+#define KEY_DELAY_DEF           "defDelay"
+#define KEY_DELAY               "delay"
+#define KEY_SCREENSHOT_TYPE_DEF "defScreenshotType"
+#define KEY_SCREENSHOT_TYPE     "screenshotType"
+#define KEY_IMG_QUALITY         "imageQuality"
+#define KEY_FILENAMEDATE        "insDateTimeInFilename"
+#define KEY_DATETIME_TPL        "templateDateTime"
+#define KEY_FILENAME_TO_CLB     "CopyFilenameToClipboard"
+#define KEY_AUTOSAVE            "autoSave"
+#define KEY_AUTOSAVE_FIRST      "autoSaveFirst"
 
-const QString KEY_CLOSE_INTRAY = "closeInTray";
-const QString KEY_TYPE_SCREEN = "typeScreenDefault";
-const QString KEY_LAST_SCREEN_TYPE = "lastScreenType";
-const QString KEY_SAVE_LAST_SCREEN_TYPE = "saveLastScreenType";
+#define KEY_SHOW_TRAY           "showTrayIcon"
+#define KEY_CLOSE_INTRAY        "closeInTray"
+#define KEY_TRAYMESSAGES        "trayMessages"
 
-const QString KEY_ENABLE_EXT_VIEWER = "enbaleExternalView";
+#define KEY_WND_WIDTH           "windowWidth"
+#define KEY_WND_HEIGHT          "windowHeight"
+#define KEY_ZOOMBOX             "zoomAroundMouse"
+#define KEY_TIME_NOTIFY         "timeTrayMessages"
+#define KEY_ALLOW_COPIES        "AllowCopies"
+#define KEY_ENABLE_EXT_VIEWER   "enbaleExternalView"
+#define KEY_NODECOR             "noDecorations"
+#define KEY_INCLUDE_CURSOR      "includeCursor"
 
-#ifdef Q_WS_X11
-const QString KEY_NODECOR = "noDecorations";
-#endif
+
+static const QLatin1String FullScreen("FullScreen");
+static const QLatin1String Window("Window");
+static const QLatin1String Area("Area");
+static const QLatin1String PreviousSelection("PreviousSelection");
+
+static QString screenshotTypeToString(int v);
+static int screenshotTypeFromString(const QString& str);
+
+static QString screenshotTypeToString(int v)
+{
+    QString r;
+
+    switch(v) {
+    case Core::FullScreen:
+        r = FullScreen;
+        break;
+    case Core::Window:
+        r = Window;
+        break;
+    case Core::Area:
+        r = Area;
+        break;
+    case Core::PreviousSelection:
+        r = PreviousSelection;
+        break;
+    default:
+        r = FullScreen;
+    }
+    return r;
+}
+
+static int screenshotTypeFromString(const QString& str)
+{
+    int r;
+
+    if (str == FullScreen)
+        r = Core::FullScreen;
+    else if (str == Window)
+        r = Core::Window;
+    else if (str == Area)
+        r = Core::Area;
+    else if (str == PreviousSelection)
+        r = Core::PreviousSelection;
+    else
+        r = Core::FullScreen; // Default
+
+    return r;
+}
 
 Config* Config::ptrInstance = 0;
 
 // constructor
 Config::Config()
 {
-    _settings = new QSettings(getConfigFile(), QSettings::IniFormat );
+    _settings = new QSettings(getConfigFile(), QSettings::IniFormat);
 
     _shortcuts = new ShortcutManager(_settings);
 
@@ -74,22 +120,17 @@ Config::Config()
     if (!QFile::exists(getConfigFile()))
     {
         // creating conf file from set defaults
-		QFile cf(getConfigFile());
-		if (cf.open(QIODevice::WriteOnly))
-		{
-			cf.close();
-			qDebug() << "creating";
-		}
-		
+        QFile cf(getConfigFile());
+        if (cf.open(QIODevice::WriteOnly))
+        {
+            cf.close();
+        }
+
         setDefaultSettings();
         saveSettings();
     }
 
-    _imageFormats << "png" << "jpg" << "bmp";
-
-#if QT_VERSION >= 0x040500
     _settings->setIniCodec("UTF-8");
-#endif
     _scrNum = 0;
 }
 
@@ -102,9 +143,7 @@ Config::~Config()
 Config* Config::instance()
 {
     if (!ptrInstance)
-    {
         ptrInstance = new Config;
-    }
 
     return ptrInstance;
 }
@@ -130,75 +169,31 @@ void Config::killInstance()
 
 QString Config::getConfigFile()
 {
-    QString configFile;
-
-#ifdef Q_WS_X11
-    configFile = Config::getConfigDir() + "screengrab.conf";
-    
-    // moving old stile storange setting to XDG_CONFIG_HOME storage
-    QString oldConfigFile = QDir::homePath()+ QDir::separator()+".screengrab"+ QDir::separator() + "screengrab.conf";
-    if (QFile::exists(oldConfigFile) == true && QFile::exists(configFile) == false)
-    {
-        QFile::rename(oldConfigFile, configFile);
-    }
-#endif
-
-#ifdef Q_WS_WIN
-    configFile = Config::getConfigDir() +"screengrab.ini";
-#endif	
-    return configFile;
+    return getConfigDir() + QDir::separator() + CONFIG_FILE_NAME;
 }
 
 QString Config::getConfigDir()
 {
-    QString configDir;
-#ifdef Q_WS_X11
-    #ifdef SG_XDG_CONFIG_SUPPORT
-        // old style config path    
-        QString oldConfigDir = QDir::homePath()+ QDir::separator()+".screengrab"+ QDir::separator();
-        configDir = qgetenv("XDG_CONFIG_HOME");
-        
-        // Ubuntu hack -- if XDG_CONFIG_HOME is missing
-        if (configDir.isEmpty() == true)
-        {
-            configDir = QDir::homePath();
-            configDir += QDir::separator();
-            configDir += ".config";
-        }
-        
-        configDir.append(QDir::separator());
-        configDir.append("screengrab");
-        configDir.append(QDir::separator());
-    #else
-        configDir = QDir::homePath()+ QDir::separator()+".screengrab"+ QDir::separator();
-    #endif
-#endif
-    
-    // if win32
-#ifdef Q_WS_WIN
-    configDir.append(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "ScreenGrab" + QDir::toNativeSeparators(QDir::separator()));
-#endif
-	
-	if (QFile::exists(configDir) == false)
-	{
-		QDir confDir(configDir);
-		confDir.mkpath(confDir.path());
-	}
-    return configDir;
-}
+    QString dir = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation);
+    dir += QDir::separator();
+    dir += CONFIG_FILE_DIR;
 
+    QDir qdir(dir);
+    if (!qdir.exists())
+        qdir.mkpath(dir);
+
+    return dir;
+}
 
 // public methods
 
 QString Config::getScrNumStr()
 {
     QString str = QString::number(_scrNum);
-    
+
     if (_scrNum < 10)
-    {
         str.prepend("0");
-    }
-    
+
     return str;
 }
 
@@ -229,14 +224,23 @@ QDateTime Config::getLastSaveDate() const
 
 bool Config::getEnableExtView()
 {
-	return value(KEY_ENABLE_EXT_VIEWER).toBool();
+    return value(KEY_ENABLE_EXT_VIEWER).toBool();
 }
 
 void Config::setEnableExtView(bool val)
 {
-	setValue(KEY_ENABLE_EXT_VIEWER, val);
+    setValue(KEY_ENABLE_EXT_VIEWER, val);
 }
 
+bool Config::getIncludeCursor()
+{
+    return value(KEY_INCLUDE_CURSOR).toBool();
+}
+
+void Config::setIncludeCursor(bool val)
+{
+    setValue(KEY_INCLUDE_CURSOR, val);
+}
 
 QString Config::getSaveDir()
 {
@@ -288,6 +292,26 @@ void Config::setDelay(quint8 sec)
     setValue(KEY_DELAY, sec);
 }
 
+int Config::getDefScreenshotType()
+{
+    return (value(QLatin1String(KEY_SCREENSHOT_TYPE_DEF)).toInt());
+}
+
+void Config::setDefScreenshotType(const int type)
+{
+    setValue(QLatin1String(KEY_SCREENSHOT_TYPE_DEF), type);
+}
+
+int Config::getScreenshotType()
+{
+    return (value(QLatin1String(KEY_SCREENSHOT_TYPE)).toInt());
+}
+
+void Config::setScreenshotType(const int type)
+{
+    setValue(QLatin1String(KEY_SCREENSHOT_TYPE), type);
+}
+
 quint8 Config::getAutoCopyFilenameOnSaving()
 {
     return value(KEY_FILENAME_TO_CLB).toInt();
@@ -329,36 +353,6 @@ void Config::setCloseInTray(bool val)
     setValue(KEY_CLOSE_INTRAY, val);
 }
 
-int Config::getTypeScreen()
-{
-    return value(KEY_TYPE_SCREEN).toInt();
-}
-
-void Config::setTypeScreen(quint8 type)
-{
-    setValue(KEY_TYPE_SCREEN, type);
-}
-
-int Config::getLastTypeScreen()
-{
-    return value(KEY_LAST_SCREEN_TYPE).toInt();
-}
-
-void Config::setLastTypeScreen(quint8 type)
-{
-    setValue(KEY_LAST_SCREEN_TYPE, type);
-}
-
-bool Config::getSaveLastTypeScreen()
-{
-    return value(KEY_SAVE_LAST_SCREEN_TYPE).toBool();
-}
-
-void Config::setSaveLastTypeScreen(bool save)
-{
-    setValue(KEY_SAVE_LAST_SCREEN_TYPE, save);
-}
-
 quint8 Config::getTimeTrayMess()
 {
     return value(KEY_TIME_NOTIFY).toInt();
@@ -421,7 +415,6 @@ void Config::setAutoSaveFirst(bool val)
     setValue(KEY_AUTOSAVE_FIRST, val);
 }
 
-
 QString Config::getDateTimeTpl()
 {
     return value(KEY_DATETIME_TPL).toString();
@@ -452,17 +445,15 @@ void Config::setShowTrayIcon(bool val)
     setValue(KEY_SHOW_TRAY, val);
 }
 
-#ifdef Q_WS_X11
-bool Config::getNoDecorX11()
+bool Config::getNoDecoration()
 {
     return value(KEY_NODECOR).toBool();
 }
 
-void Config::setNoDecorX11(bool val)
+void Config::setNoDecoration(bool val)
 {
     setValue(KEY_NODECOR, val);
 }
-#endif
 
 void Config::saveWndSize()
 {
@@ -481,23 +472,15 @@ void Config::loadSettings()
     setSaveFileName(_settings->value(KEY_SAVENAME,DEF_SAVE_NAME).toString());
     setSaveFormat(_settings->value(KEY_SAVEFORMAT, DEF_SAVE_FORMAT).toString());
     setDefDelay(_settings->value(KEY_DELAY, DEF_DELAY).toInt());
+    setDefScreenshotType(screenshotTypeFromString(_settings->value(QLatin1String(KEY_SCREENSHOT_TYPE_DEF)).toString()));
     setAutoCopyFilenameOnSaving(_settings->value(KEY_FILENAME_TO_CLB, DEF_FILENAME_TO_CLB).toInt());
     setDateTimeInFilename(_settings->value(KEY_FILENAMEDATE, DEF_DATETIME_FILENAME).toBool());
     setDateTimeTpl(_settings->value(KEY_DATETIME_TPL, DEF_DATETIME_TPL).toString());
     setAutoSave(_settings->value(KEY_AUTOSAVE, DEF_AUTO_SAVE).toBool());
     setAutoSaveFirst(_settings->value(KEY_AUTOSAVE_FIRST, DEF_AUTO_SAVE_FIRST).toBool());
-#ifdef Q_WS_X11
-    setNoDecorX11(_settings->value(KEY_NODECOR, DEF_X11_NODECOR).toBool());
-#endif
+    setNoDecoration(_settings->value(KEY_NODECOR, DEF_X11_NODECOR).toBool());
     setImageQuality(_settings->value(KEY_IMG_QUALITY, DEF_IMG_QUALITY).toInt());
-
-    setSaveLastTypeScreen(_settings->value(KEY_SAVE_LAST_SCREEN_TYPE, DEF_SAVE_LAST_SCREEN_TYPE).toBool());
-
-    if (getSaveLastTypeScreen()) {
-        setLastTypeScreen(_settings->value(KEY_LAST_SCREEN_TYPE, DEF_LAST_SCREEN_TYPE).toInt());
-        setTypeScreen(getLastTypeScreen());
-    }
-
+    setIncludeCursor(_settings->value(KEY_INCLUDE_CURSOR, DEF_INCLUDE_CURSOR).toBool());
     _settings->endGroup();
 
     _settings->beginGroup("Display");
@@ -505,14 +488,15 @@ void Config::loadSettings()
     setTimeTrayMess(_settings->value(KEY_TIME_NOTIFY, DEF_TIME_TRAY_MESS).toInt( ));
     setZoomAroundMouse(_settings->value(KEY_ZOOMBOX, DEF_ZOOM_AROUND_MOUSE).toBool());
     // TODO - make set windows size without hardcode values
-	setRestoredWndSize(_settings->value(KEY_WND_WIDTH, DEF_WND_WIDTH).toInt(), _settings->value(KEY_WND_HEIGHT, DEF_WND_HEIGHT).toInt());
+    setRestoredWndSize(_settings->value(KEY_WND_WIDTH, DEF_WND_WIDTH).toInt(),
+                       _settings->value(KEY_WND_HEIGHT, DEF_WND_HEIGHT).toInt());
     setShowTrayIcon(_settings->value(KEY_SHOW_TRAY, DEF_SHOW_TRAY).toBool());
     _settings->endGroup();
 
     _settings->beginGroup("System");
     setCloseInTray(_settings->value(KEY_CLOSE_INTRAY, DEF_CLOSE_IN_TRAY).toBool());
     setAllowMultipleInstance(_settings->value(KEY_ALLOW_COPIES, DEF_ALLOW_COPIES).toBool());
-	setEnableExtView(_settings->value(KEY_ENABLE_EXT_VIEWER, DEF_ENABLE_EXT_VIEWER).toBool());
+    setEnableExtView(_settings->value(KEY_ENABLE_EXT_VIEWER, DEF_ENABLE_EXT_VIEWER).toBool());
     _settings->endGroup();
 
     setDelay(getDefDelay());
@@ -527,25 +511,20 @@ void Config::saveSettings()
     _settings->setValue(KEY_SAVENAME, getSaveFileName());
     _settings->setValue(KEY_SAVEFORMAT, getSaveFormat());
     _settings->setValue(KEY_DELAY, getDefDelay());
+    _settings->setValue(QLatin1String(KEY_SCREENSHOT_TYPE_DEF), screenshotTypeToString(getDefScreenshotType()));
     _settings->setValue(KEY_FILENAME_TO_CLB, getAutoCopyFilenameOnSaving());
     _settings->setValue(KEY_FILENAMEDATE, getDateTimeInFilename());
     _settings->setValue(KEY_DATETIME_TPL, getDateTimeTpl());
     _settings->setValue(KEY_AUTOSAVE, getAutoSave());
     _settings->setValue(KEY_AUTOSAVE_FIRST, getAutoSaveFirst());
     _settings->setValue(KEY_IMG_QUALITY, getImageQuality());
-    _settings->setValue(KEY_SAVE_LAST_SCREEN_TYPE, getSaveLastTypeScreen());
-
-    if (getSaveLastTypeScreen() == true) {
-        _settings->setValue(KEY_LAST_SCREEN_TYPE, getTypeScreen());
-    }
-#ifdef Q_WS_X11
-    _settings->setValue(KEY_NODECOR, getNoDecorX11());
-#endif
+    _settings->setValue(KEY_NODECOR, getNoDecoration());
+    _settings->setValue(KEY_INCLUDE_CURSOR, getIncludeCursor());
     _settings->endGroup();
 
     _settings->beginGroup("Display");
     _settings->setValue(KEY_TRAYMESSAGES, getTrayMessages());
-    _settings->setValue(KEY_TIME_NOTIFY, getTimeTrayMess());    
+    _settings->setValue(KEY_TIME_NOTIFY, getTimeTrayMess());
     _settings->setValue(KEY_ZOOMBOX, getZoomAroundMouse());
     _settings->setValue(KEY_SHOW_TRAY, getShowTrayIcon());
     _settings->endGroup();
@@ -554,11 +533,11 @@ void Config::saveSettings()
     _settings->beginGroup("System");
     _settings->setValue(KEY_CLOSE_INTRAY, getCloseInTray());
     _settings->setValue(KEY_ALLOW_COPIES, getAllowMultipleInstance());
-	_settings->setValue(KEY_ENABLE_EXT_VIEWER, getEnableExtView());
+    _settings->setValue(KEY_ENABLE_EXT_VIEWER, getEnableExtView());
     _settings->endGroup();
 
     _shortcuts->saveSettings();
-    
+
     resetScrNum();
 }
 
@@ -569,47 +548,38 @@ void Config::setDefaultSettings()
     setSaveFileName(DEF_SAVE_NAME);
     setSaveFormat(DEF_SAVE_FORMAT);
     setDefDelay(DEF_DELAY);
+    setScreenshotType(Core::FullScreen);
     setImageQuality(DEF_IMG_QUALITY);
-    setSaveLastTypeScreen(DEF_SAVE_LAST_SCREEN_TYPE);
     setDateTimeInFilename(DEF_DATETIME_FILENAME);
     setDateTimeTpl(DEF_DATETIME_TPL);
     setAutoCopyFilenameOnSaving(DEF_FILENAME_TO_CLB);
     setAutoSave(DEF_AUTO_SAVE);
     setAutoSaveFirst(DEF_AUTO_SAVE_FIRST);
     setTrayMessages(DEF_TRAY_MESS_TYPE);
+    setIncludeCursor(DEF_INCLUDE_CURSOR);
     setZoomAroundMouse(DEF_ZOOM_AROUND_MOUSE);
     setCloseInTray(DEF_CLOSE_IN_TRAY);
     setTimeTrayMess(DEF_TIME_TRAY_MESS);
     setAllowMultipleInstance(DEF_ALLOW_COPIES);
-	// TODO - make set windows size without hardcode values
+    // TODO - make set windows size without hardcode values
     // setRestoredWndSize(DEF_WND_WIDTH, DEF_WND_HEIGHT);
     setShowTrayIcon(DEF_SHOW_TRAY);
-	setEnableExtView(DEF_ENABLE_EXT_VIEWER);
+    setEnableExtView(DEF_ENABLE_EXT_VIEWER);
 
     _shortcuts->setDefaultSettings();
 
-#ifdef Q_WS_X11
-    setNoDecorX11(DEF_X11_NODECOR);
-#endif
-
+    setNoDecoration(DEF_X11_NODECOR);
     setDelay(DEF_DELAY);
 
-	quint8 countModules = Core::instance()->modules()->count();	
-	for (int i = 0; i < countModules; ++i) 
-	{
-		Core::instance()->modules()->getModule(i)->defaultSettings();
-	}
+    quint8 countModules = Core::instance()->modules()->count();
+    for (int i = 0; i < countModules; ++i)
+        Core::instance()->modules()->getModule(i)->defaultSettings();
 }
 
 // get defaukt directory path
 QString Config::getDirNameDefault()
 {
-#ifdef Q_WS_X11
-    return QDir::homePath()+QDir::separator();    ;
-#endif
-#ifdef Q_WS_WIN
-    return QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + QDir::separator() ;
-#endif
+    return QDir::homePath()+QDir::separator();
 }
 
 // get id of default save format
@@ -620,37 +590,20 @@ int Config::getDefaultFormatID()
 
 QString Config::getSysLang()
 {
-#ifdef Q_WS_X11
     QByteArray lang = qgetenv("LC_ALL");
 
     if (lang.isEmpty())
-    {
         lang = qgetenv("LC_MESSAGES");
-    }
+
     if (lang.isEmpty())
-    {
         lang = qgetenv("LANG");
-    }
+
     if (!lang.isEmpty())
-    {
         return QLocale (lang).name();
-    }
     else
-    {
         return  QLocale::system().name();
-    }
-#endif
-#ifdef Q_WS_WIN
-    return  QLocale::system().name();
-#endif
 }
 
-
-// CmdLine* Config::cmdLine()
-// {
-//     return cmd;
-// }
-
 ShortcutManager* Config::shortcuts()
 {
     return _shortcuts;
