@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009 - 2013 by Artem 'DOOMer' Galichkin                        *
+ *   Copyright (C) 2009 - 2013 by Artem 'DOOMer' Galichkin                 *
  *   doomer3d@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -13,9 +13,7 @@
  *   GNU General Public License for more details.                          *
  *                                                                         *
  *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
 #ifndef REGIONSELECT_H
@@ -23,14 +21,14 @@
 
 #include "config.h"
 
-//#include <QtGui/QDialog>
-#include <QtGui/QWidget>
+//#include <QDialog>
+#include <QWidget>
 
-#include <QtGui/QMouseEvent>
-#include <QtGui/QPainter>
-#include <QtGui/QPixmap>
-#include <QtCore/QSize>
-#include <QtCore/QPoint>
+#include <QMouseEvent>
+#include <QPainter>
+#include <QPixmap>
+#include <QSize>
+#include <QPoint>
 
 // class RegionSelect : public QDialog
 class RegionSelect : public QWidget
@@ -38,10 +36,10 @@ class RegionSelect : public QWidget
     Q_OBJECT
 public:
     RegionSelect(Config *mainconf, QWidget *parent = 0);
-	RegionSelect(Config *mainconf, const QRect& lastRect, QWidget *parent = 0);
+    RegionSelect(Config *mainconf, const QRect& lastRect, QWidget *parent = 0);
     virtual ~RegionSelect();
     QPixmap getSelection();
-	QPoint getSelectionStartPos();
+    QPoint getSelectionStartPos();
 
 protected:
     void paintEvent(QPaintEvent *event);
@@ -66,7 +64,7 @@ private:
     QPixmap _desktopPixmapBkg;
     QPixmap _desktopPixmapClr;
 
-	void sharedInit();
+    void sharedInit();
     void drawBackGround();
     void drawRectSelection(QPainter &painter);
 
